@@ -1,6 +1,6 @@
-REM  $Header: /Users/claude/fuzz/lib/Genezzo/RCS/dict.sql,v 1.8 2006/03/30 07:21:49 claude Exp claude $
+REM  $Header: /Users/claude/fuzz/lib/Genezzo/RCS/dict.sql,v 1.9 2006/05/07 06:47:09 claude Exp claude $
 REM
-REM $Revision: 1.8 $
+REM $Revision: 1.9 $
 REM
 REM copyright (c) 2005, 2006 Jeffrey I Cohen, all rights reserved, worldwide
 REM
@@ -22,5 +22,10 @@ alter table _tspace add constraint tspace_tsname_uk unique (tsname);
 create table dual (dummy varchar(1));
 insert into dual values ('X');
 
+select HavokUse('Genezzo::Havok') from dual;
+select HavokUse('Genezzo::Havok::SQLScalar') from dual;
+
+
+
 REM always commit changes!!
 commit ;
